From 150de0a7a943b6bc1ff99e737d896f39abd21ad0 Mon Sep 17 00:00:00 2001
From: TheBrokenRail
Date: Tue, 30 Nov 2021 21:40:02 -0500
Subject: [PATCH] Rename Package
---
CMakeLists.txt | 6 +++---
Dockerfile | 2 +-
Jenkinsfile | 4 ++--
README.md | 2 +-
docs/DEDICATED_SERVER.md | 6 +++---
docs/INSTALL.md | 2 +-
docs/SOUND.md | 2 +-
example-mods/README.md | 4 ++--
example-mods/chat-commands/CMakeLists.txt | 2 +-
example-mods/expanded-creative/CMakeLists.txt | 2 +-
example-mods/recipes/CMakeLists.txt | 2 +-
launcher/src/bootstrap.c | 2 +-
launcher/src/crash-report.c | 2 +-
scripts/package.sh | 4 ++--
scripts/test.sh | 8 ++++----
15 files changed, 25 insertions(+), 25 deletions(-)
diff --git a/CMakeLists.txt b/CMakeLists.txt
index a64a561c..80d17661 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -34,7 +34,7 @@ if(NOT MCPI_HEADLESS_MODE)
endif()
# App ID
-set(DEFAULT_APP_ID "com.thebrokenrail.MCPIReborn")
+set(DEFAULT_APP_ID "com.thebrokenrail.MCPIRebornLegacy")
if(MCPI_SERVER_MODE)
string(APPEND DEFAULT_APP_ID "Server")
else()
@@ -43,7 +43,7 @@ endif()
set(MCPI_APP_ID "${DEFAULT_APP_ID}" CACHE STRING "App ID")
# App Title
-set(DEFAULT_APP_TITLE "Minecraft: Pi Edition: Reborn")
+set(DEFAULT_APP_TITLE "Minecraft: Pi Edition: Reborn Legacy")
if(MCPI_SERVER_MODE)
string(APPEND DEFAULT_APP_TITLE " (Server)")
else()
@@ -52,7 +52,7 @@ endif()
set(MCPI_APP_TITLE "${DEFAULT_APP_TITLE}" CACHE STRING "App Title")
# Specify Variant Name
-set(MCPI_VARIANT_NAME "minecraft-pi-reborn")
+set(MCPI_VARIANT_NAME "minecraft-pi-reborn-legacy")
if(MCPI_SERVER_MODE)
string(APPEND MCPI_VARIANT_NAME "-server")
else()
diff --git a/Dockerfile b/Dockerfile
index ad9cd984..bba50ae8 100644
--- a/Dockerfile
+++ b/Dockerfile
@@ -16,4 +16,4 @@ WORKDIR /data
# Setup Entrypoint
ENTRYPOINT ["/usr/bin/tini", "--"]
-CMD ["/app/usr/bin/minecraft-pi-reborn-server"]
+CMD ["/app/usr/bin/minecraft-pi-reborn-legacy-server"]
diff --git a/Jenkinsfile b/Jenkinsfile
index ad2dc96a..389d795b 100644
--- a/Jenkinsfile
+++ b/Jenkinsfile
@@ -24,11 +24,11 @@ pipeline {
sh 'apt-get update && apt-get install -y docker.io'
sh 'rm -rf ./out/server-amd64'
sh './scripts/build.sh server amd64'
- sh 'docker build --no-cache --tag thebrokenrail/minecraft-pi-reborn-server .'
+ sh 'docker build --no-cache --tag thebrokenrail/minecraft-pi-reborn-legacy-server .'
withCredentials([usernamePassword(credentialsId: 'docker_hub_login', usernameVariable: 'DOCKER_HUB_USERNAME', passwordVariable: 'DOCKER_HUB_PASSWORD')]) {
sh 'docker login -u "${DOCKER_HUB_USERNAME}" -p "${DOCKER_HUB_PASSWORD}"'
}
- sh 'docker push thebrokenrail/minecraft-pi-reborn-server'
+ sh 'docker push thebrokenrail/minecraft-pi-reborn-legacy-server'
}
}
}
diff --git a/README.md b/README.md
index c5b0efeb..39c4ac4d 100644
--- a/README.md
+++ b/README.md
@@ -2,7 +2,7 @@
-# Minecraft: Pi Edition: Reborn
+# Minecraft: Pi Edition: Reborn Legacy
Minecraft: Pi Edition Modding Project
## Documentation
diff --git a/docs/DEDICATED_SERVER.md b/docs/DEDICATED_SERVER.md
index a9242fad..10fe0572 100644
--- a/docs/DEDICATED_SERVER.md
+++ b/docs/DEDICATED_SERVER.md
@@ -1,15 +1,15 @@
# Dedicated Server
The dedicated server is a version of Minecraft: Pi Edition modified to run in a headless environment. It loads settings from a ``server.properties`` file.
-This server is also compatible with MCPE Alpha v0.6.1[^1].
+This server is also compatible with MCPE Alpha v0.5.0[^1].
## Setup
### Debian Package
-To use, install and run ``minecraft-pi-reborn-server``. It will generate the world and ``server.properties`` in the current directory.
+To use, install and run ``minecraft-pi-reborn-legacy-server``. It will generate the world and ``server.properties`` in the current directory.
### Docker Image
-An official Docker image is also provided: [thebrokenrail/minecraft-pi-reborn-server](https://hub.docker.com/r/thebrokenrail/minecraft-pi-reborn-server).
+An official Docker image is also provided: [thebrokenrail/minecraft-pi-reborn-legacy-server](https://hub.docker.com/r/thebrokenrail/minecraft-pi-reborn-legacy-server).
## Server Limitations
* Player data is not saved because of limitations with MCPE LAN worlds
diff --git a/docs/INSTALL.md b/docs/INSTALL.md
index d409934c..02a567a8 100644
--- a/docs/INSTALL.md
+++ b/docs/INSTALL.md
@@ -1,7 +1,7 @@
# Installation
## AppImage
-Download packages [here](https://jenkins.thebrokenrail.com/job/minecraft-pi-reborn/job/master/lastSuccessfulBuild/artifact/out/).
+Download packages [here](https://jenkins.thebrokenrail.com/job/minecraft-pi-reborn/job/legacy/lastSuccessfulBuild/artifact/out/).
### System Requirements
* Debian Buster/Ubuntu 18.04 Or Higher
diff --git a/docs/SOUND.md b/docs/SOUND.md
index f438a1d8..4d5b020f 100644
--- a/docs/SOUND.md
+++ b/docs/SOUND.md
@@ -1,7 +1,7 @@
# Sound
One of MCPI-Reborn's main modifications is a sound-engine since MCPI doesn't include one by default[^1]. However, it can't be used out-of-box because MCPI doesn't contain any sound data and MCPI-Reborn can't include it because of copyright.
-MCPE's sound data can be extracted from any MCPE v0.6.1[^2] APK file, just place its `libminecraftpe.so` into `~/.minecraft-pi/overrides` and you should have sound!
+MCPE's sound data can be extracted from any MCPE v0.5.0[^2] APK file, just place its `libminecraftpe.so` into `~/.minecraft-pi/overrides` and you should have sound!
[^1]: The mute button is just leftover code from MCPE, it doesn't actually do anything in un-modded MCPI, however it is connected to MCPI-Reborn's sound-engine.
[^2]: This isn't a hard limit, an MCPE v0.8.1 APK would probably work, but don't rely on it.
diff --git a/example-mods/README.md b/example-mods/README.md
index 926f6126..aadb0a32 100644
--- a/example-mods/README.md
+++ b/example-mods/README.md
@@ -8,12 +8,12 @@ This is an example of a mod that cane be built using the modding SDK.
## The SDK
The modding SDK is a collection of exported CMake targets that allows anyone to create their own MCPI mod!
-The SDK is copied to ``~/.minecraft-pi/sdk/lib/minecraft-pi-reborn-client/sdk/sdk.cmake`` whenever MCPI-Reborn is started.
+The SDK is copied to ``~/.minecraft-pi/sdk/lib/minecraft-pi-reborn-legacy-client/sdk/sdk.cmake`` whenever MCPI-Reborn is started.
## How do I use this?
```sh
mkdir build
cd build
cmake ..
-cp libexpanded-creative.so ~/.minecraft-pi/mods
+cp libexpanded-creative.so ~/.minecraft-pi/legacy-mods
```
diff --git a/example-mods/chat-commands/CMakeLists.txt b/example-mods/chat-commands/CMakeLists.txt
index 84fef6a8..8e4761ee 100644
--- a/example-mods/chat-commands/CMakeLists.txt
+++ b/example-mods/chat-commands/CMakeLists.txt
@@ -8,7 +8,7 @@ set(CMAKE_CXX_COMPILER arm-linux-gnueabihf-g++)
project(chat-commands)
# Include SDK
-include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-client/sdk/sdk.cmake")
+include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-legacy-client/sdk/sdk.cmake")
# Build
add_library(chat-commands SHARED chat-commands.cpp)
diff --git a/example-mods/expanded-creative/CMakeLists.txt b/example-mods/expanded-creative/CMakeLists.txt
index 258f3e83..e3d512f3 100644
--- a/example-mods/expanded-creative/CMakeLists.txt
+++ b/example-mods/expanded-creative/CMakeLists.txt
@@ -8,7 +8,7 @@ set(CMAKE_CXX_COMPILER arm-linux-gnueabihf-g++)
project(expanded-creative)
# Include SDK
-include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-client/sdk/sdk.cmake")
+include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-legacy-client/sdk/sdk.cmake")
# Build
add_library(expanded-creative SHARED expanded-creative.cpp)
diff --git a/example-mods/recipes/CMakeLists.txt b/example-mods/recipes/CMakeLists.txt
index cdf6bce8..be02e919 100644
--- a/example-mods/recipes/CMakeLists.txt
+++ b/example-mods/recipes/CMakeLists.txt
@@ -8,7 +8,7 @@ set(CMAKE_CXX_COMPILER arm-linux-gnueabihf-g++)
project(recipes)
# Include SDK
-include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-client/sdk/sdk.cmake")
+include("$ENV{HOME}/.minecraft-pi/sdk/lib/minecraft-pi-reborn-legacy-client/sdk/sdk.cmake")
# Build
add_library(recipes SHARED recipes.cpp)
diff --git a/launcher/src/bootstrap.c b/launcher/src/bootstrap.c
index 718e4467..256447b4 100644
--- a/launcher/src/bootstrap.c
+++ b/launcher/src/bootstrap.c
@@ -389,7 +389,7 @@ void bootstrap(int argc, char *argv[]) {
{
// Get Mods Folder
char *mods_folder = NULL;
- safe_asprintf(&mods_folder, "%s" HOME_SUBDIRECTORY_FOR_GAME_DATA "/mods/", getenv("HOME"));
+ safe_asprintf(&mods_folder, "%s" HOME_SUBDIRECTORY_FOR_GAME_DATA "/legacy-mods/", getenv("HOME"));
// Load Mods From ./mods
load(&preload, mods_folder);
// Free Mods Folder
diff --git a/launcher/src/crash-report.c b/launcher/src/crash-report.c
index 88bf4b2e..a632b566 100644
--- a/launcher/src/crash-report.c
+++ b/launcher/src/crash-report.c
@@ -26,7 +26,7 @@ static void show_report(const char *log_filename) {
"--width", CRASH_REPORT_DIALOG_WIDTH,
"--height", CRASH_REPORT_DIALOG_HEIGHT,
"--text-info",
- "--text", "Minecraft: Pi Edition: Reborn has crashed!\n\nNeed help? Consider asking on the Discord server!",
+ "--text", "Minecraft: Pi Edition: Reborn Legacy has crashed!\n\nNeed help? Consider asking on the Discord server!",
"--filename", log_filename,
"--no-wrap",
"--font", "Monospace",
diff --git a/scripts/package.sh b/scripts/package.sh
index 9e85e065..36b28a01 100755
--- a/scripts/package.sh
+++ b/scripts/package.sh
@@ -3,8 +3,8 @@
set -e
# Prepare
-NAME='minecraft-pi-reborn'
-BRANCH='master'
+NAME='minecraft-pi-reborn-legacy'
+BRANCH='legacy'
# Build
./scripts/setup.sh "$1" "$2" -DMCPI_IS_APPIMAGE_BUILD=ON
diff --git a/scripts/test.sh b/scripts/test.sh
index d8e8558c..cff6d7b0 100755
--- a/scripts/test.sh
+++ b/scripts/test.sh
@@ -7,7 +7,7 @@ ARCH="$(dpkg-architecture -qDEB_BUILD_ARCH)"
./scripts/setup.sh server "${ARCH}"
./scripts/build.sh server "${ARCH}"
# Add minecraft-pi-reborn-server To PATH
export PATH="$(pwd)/out/server-$(dpkg-architecture -qDEB_BUILD_ARCH)/usr/bin:${PATH}"
# Create Test Directory
@@ -16,14 +16,14 @@ mkdir -p build/test
# Run Test
cd build/test
-minecraft-pi-reborn-server --only-generate
+minecraft-pi-reborn-legacy-server --only-generate
cd ../../
# Build Benchmark
./scripts/setup.sh client "${ARCH}" -DMCPI_HEADLESS_MODE=ON
./scripts/build.sh client "${ARCH}"
# Add minecraft-pi-reborn-client To PATH
export PATH="$(pwd)/out/client-$(dpkg-architecture -qDEB_BUILD_ARCH)/usr/bin:${PATH}"
# Skip Root Check
@@ -31,4 +31,4 @@ export _MCPI_SKIP_ROOT_CHECK=1
# Run Benchmark
export HOME="$(pwd)/build/test"
-minecraft-pi-reborn-client --default --benchmark
+minecraft-pi-reborn-legacy-client --default --benchmark
@@ -7,7 +7,7 @@ ARCH="$(dpkg-architecture -qDEB_BUILD_ARCH)"
./scripts/setup.sh server "${ARCH}"
./scripts/build.sh server "${ARCH}"
-# Add minecraft-pi-reborn-server To PATH
+# Add minecraft-pi-reborn-legacy-server To PATH
export PATH="$(pwd)/out/server-$(dpkg-architecture -qDEB_BUILD_ARCH)/usr/bin:${PATH}"
# Create Test Directory
@@ -16,14 +16,14 @@ mkdir -p build/test
./scripts/setup.sh client "${ARCH}" -DMCPI_HEADLESS_MODE=ON
./scripts/build.sh client "${ARCH}"
-# Add minecraft-pi-reborn-client To PATH
+# Add minecraft-pi-reborn-legacy-client To PATH
export PATH="$(pwd)/out/client-$(dpkg-architecture -qDEB_BUILD_ARCH)/usr/bin:${PATH}"
# Skip Root Check